@@ -159,7 +159,7 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         self.prefix = kwargs.get('prefix', '/usr/local/gnu')
         self.__source = kwargs.get('source', False)
         self.__version = kwargs.get('version', None)
-        self.__wd = '/var/tmp' # working directory
+        self.__wd = kwargs.get('wd', hpccm.config.g_wd) # working directory
 
         self.__commands = []       # Filled in below
         self.__compiler_debs = []  # Filled in below
@@ -182,6 +182,24 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         # Fill in container instructions
         self.__instructions()
 
+    def __configure_toolchain_on_build(self):
+
+        directory = posixpath.join(self.prefix, 'bin')
+
+        if self.__cc:
+            self.toolchain.CC = posixpath.join(directory, 'gcc')
+
+        if self.__cxx:
+            self.toolchain.CXX = posixpath.join(directory, 'g++')
+
+        if self.__fortran:
+            self.toolchain.FC = posixpath.join(directory, 'gfortran')
+            self.toolchain.F77 = posixpath.join(directory, 'gfortran')
+            self.toolchain.F90 = posixpath.join(directory, 'gfortran')
+
+        if "LD_LIBRARY_PATH" in self.environment_variables:
+            self.toolchain.LD_LIBRARY_PATH = self.environment_variables["LD_LIBRARY_PATH"]
+
     def __build(self):
         """Build compilers from source"""
 
@@ -291,6 +309,9 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         else:
             self.environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(posixpath.join(self.prefix, 'lib64'))
 
+        # Setup toolchain
+        self.__configure_toolchain_on_build()
+
         # Cleanup
         self.__commands.append(self.cleanup_step(
             items=[posixpath.join(self.__wd, tarball),
@@ -316,44 +337,55 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
             else: # pragma: no cover
                 raise RuntimeError('Unknown Linux distribution')
 
-        elif self.__version and not self.__source:
+        else:
+            # Set libfortran version depending on the Ubuntu version
+            if self.__fortran:
+                if hpccm.config.g_linux_distro == linux_distro.UBUNTU:
+                    if hpccm.config.g_linux_version >= StrictVersion('18.0'):
+                        self.__runtime_debs.append('libgfortran4')
+                    elif hpccm.config.g_linux_version >= StrictVersion('16.0'):
+                        self.__runtime_debs.append('libgfortran3')
+                    else: # pragma: no cover
+                        raise RuntimeError('Unrecognized Ubuntu version')
+
             # Setup the environment so that the alternate compiler version
             # is the new default
-            alternatives = {}
-            if hpccm.config.g_linux_distro == linux_distro.UBUNTU:
-                if self.__cc:
-                    alternatives['gcc'] = '$(which gcc-{})'.format(
+            if self.__version:
+                alternatives = {}
+                if hpccm.config.g_linux_distro == linux_distro.UBUNTU:
+                    if self.__cc:
+                        alternatives['gcc'] = '$(which gcc-{})'.format(
+                            self.__version)
+                    if self.__cxx:
+                        alternatives['g++'] = '$(which g++-{})'.format(
+                            self.__version)
+                    if self.__fortran:
+                        alternatives['gfortran'] = '$(which gfortran-{})'.format(
+                            self.__version)
+                    alternatives['gcov'] = '$(which gcov-{})'.format(
                         self.__version)
-                if self.__cxx:
-                    alternatives['g++'] = '$(which g++-{})'.format(
+                elif hpccm.config.g_linux_distro == linux_distro.CENTOS:
+                    # Default for CentOS 7
+                    toolset_path = '/opt/rh/devtoolset-{}/root/usr/bin'.format(
                         self.__version)
-                if self.__fortran:
-                    alternatives['gfortran'] = '$(which gfortran-{})'.format(
-                        self.__version)
-                alternatives['gcov'] = '$(which gcov-{})'.format(
-                    self.__version)
-            elif hpccm.config.g_linux_distro == linux_distro.CENTOS:
-                # Default for CentOS 7
-                toolset_path = '/opt/rh/devtoolset-{}/root/usr/bin'.format(
-                    self.__version)
-                if hpccm.config.g_linux_version >= StrictVersion('8.0'):
-                    # CentOS 8
-                    toolset_path = '/opt/rh/gcc-toolset-{}/root/usr/bin'.format(self.__version)
+                    if hpccm.config.g_linux_version >= StrictVersion('8.0'):
+                        # CentOS 8
+                        toolset_path = '/opt/rh/gcc-toolset-{}/root/usr/bin'.format(self.__version)
 
-                if self.__cc:
-                    alternatives['gcc'] = posixpath.join(toolset_path, 'gcc')
-                if self.__cxx:
-                    alternatives['g++'] = posixpath.join(toolset_path, 'g++')
-                if self.__fortran:
-                    alternatives['gfortran'] = posixpath.join(toolset_path,
-                                                              'gfortran')
-                alternatives['gcov'] = posixpath.join(toolset_path, 'gcov')
+                    if self.__cc:
+                        alternatives['gcc'] = posixpath.join(toolset_path, 'gcc')
+                    if self.__cxx:
+                        alternatives['g++'] = posixpath.join(toolset_path, 'g++')
+                    if self.__fortran:
+                        alternatives['gfortran'] = posixpath.join(toolset_path,
+                                                                  'gfortran')
+                    alternatives['gcov'] = posixpath.join(toolset_path, 'gcov')
 
-            else: # pragma: no cover
-                raise RuntimeError('Unknown Linux distribution')
+                else: # pragma: no cover
+                    raise RuntimeError('Unknown Linux distribution')
 
-            for tool,alt in sorted(alternatives.items()):
-                self.__commands.append('update-alternatives --install {0} {1} {2} 30'.format(posixpath.join('/usr/bin', tool), tool, alt))
+                for tool,alt in sorted(alternatives.items()):
+                    self.__commands.append('update-alternatives --install {0} {1} {2} 30'.format(posixpath.join('/usr/bin', tool), tool, alt))
 
     def __instructions(self):
         """Fill in container instructions"""
@@ -387,7 +419,7 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
 
         if self.__fortran:
             self.__compiler_debs.append('gfortran')
-            self.__runtime_debs.append('libgfortran3')
+            # libgfortran runtime deb is set is __distro()
             self.__compiler_rpms.append('gcc-gfortran')
             self.__runtime_rpms.append('libgfortran')
             self.toolchain.F77 = 'gfortran'
@@ -428,26 +460,23 @@ class gnu(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         Stage1 += g.runtime()
         ```
         """
-        instructions = []
-        instructions.append(comment('GNU compiler runtime'))
+        self.rt += comment('GNU compiler runtime')
         if self.__source:
-            instructions.append(copy(_from=_from,
-                                     dest=posixpath.join(self.prefix, 'lib64'),
-                                     src=posixpath.join(self.prefix, 'lib64')))
+            self.rt += copy(_from=_from,
+                            dest=posixpath.join(self.prefix, 'lib64'),
+                            src=posixpath.join(self.prefix, 'lib64'))
             if self.ldconfig:
-                instructions.append(shell(
-                    commands=[self.ldcache_step(
-                        directory=posixpath.join(self.prefix, 'lib64'))]))
+                self.rt += shell(commands=[self.ldcache_step(
+                    directory=posixpath.join(self.prefix, 'lib64'))])
             else:
-                instructions.append(environment(
-                    variables=self.environment_step(
-                        include_only=['LD_LIBRARY_PATH'])))
+                self.rt += environment(variables=self.environment_step(
+                    include_only=['LD_LIBRARY_PATH']))
         else:
-            instructions.append(
-                packages(apt=self.__runtime_debs,
-                         apt_ppas=self.__extra_repo_apt,
-                         release_stream=bool(self.__version), # True / False
-                         scl=bool(self.__version), # True / False
-                         yum=self.__runtime_rpms))
+            self.rt += packages(
+                apt=self.__runtime_debs,
+                apt_ppas=self.__extra_repo_apt,
+                release_stream=bool(self.__version), # True / False
+                scl=bool(self.__version), # True / False
+                yum=self.__runtime_rpms)
 
-        return '\n'.join(str(x) for x in instructions)
+        return str(self.rt)
