@@ -145,7 +145,7 @@ class intel_psxe(bb_base, hpccm.templates.envvars, hpccm.templates.rm,
     using the [intel_psxe_runtime](#intel_psxe_runtime) building
     block.  This value is passed as its `version` parameter.  In
     general, the major version of the runtime should correspond to the
-    tarball version.  The default value is `2020.1-12`.
+    tarball version.  The default value is `2020.2-14`.
 
     tarball: Path to the Intel Parallel Studio XE tarball relative to
     the local build context.  The default value is empty.  This
@@ -193,10 +193,10 @@ class intel_psxe(bb_base, hpccm.templates.envvars, hpccm.templates.rm,
         self.__ospackages = kwargs.get('ospackages', [])
         self.__prefix = kwargs.get('prefix', '/opt/intel')
         self.__psxevars = kwargs.get('psxevars', True)
-        self.__runtime_version = kwargs.get('runtime_version', '2020.1-12')
+        self.__runtime_version = kwargs.get('runtime_version', '2020.2-14')
         self.__tarball = kwargs.get('tarball', None)
         self.__tbb = kwargs.get('tbb', True)
-        self.__wd = '/var/tmp' # working directory
+        self.__wd = kwargs.get('wd', hpccm.config.g_wd) # working directory
 
         self.toolchain = toolchain(CC='icc', CXX='icpc', F77='ifort',
                                    F90='ifort', FC='ifort')
