@@ -20,7 +20,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-from distutils.version import StrictVersion
+from distutils.version import LooseVersion, StrictVersion
 import logging
 
 import hpccm.config
@@ -46,28 +46,24 @@ class llvm(bb_base, hpccm.templates.envvars):
 
     environment: Boolean flag to specify whether the environment
     (`CPATH`, `LD_LIBRARY_PATH` and `PATH`) should be modified to
-    include the LLVM compilers. The default is True.
-
-    extra_repository: Boolean flag to specify whether to enable an extra package repository containing addition LLVM compiler packages.  For Ubuntu, setting this flag to True enables the `ppa:ubuntu-toolchain-r/test`
-    repository.  For RHEL-based Linux distributions, setting this flag
-    to True enables the Software Collections (SCL) repository.  The
-    default is False.
+    include the LLVM compilers when necessary. The default is True.
 
     extra_tools: Boolean flag to specify whether to also install
     `clang-format` and `clang-tidy`.  The default is False.
 
-    nightly: Boolean flag to specify whether to use the [nightly LLVM packages](https://apt.llvm.org).
-    This option is ignored if the base image is not Ubuntu.
+    openmp: Boolean flag to specify whether to also install OpenMP
+    support.  The default is True.
+
+    toolset: Boolean flag to specify whether to also install the
+    full LLVM toolset.  The default is False.
+
+    upstream: Boolean flag to specify whether to use the [upstream LLVM packages](https://apt.llvm.org).
+    This option is ignored if the base image is not Ubuntu-based.
 
     version: The version of the LLVM compilers to install.  Note that
     the version refers to the Linux distribution packaging, not the
-    actual compiler version.  For Ubuntu, the version is appended to
-    the default package name, e.g., `clang-6.0`.  For RHEL-based Linux
-    distributions, the version is inserted into the SCL Developer
-    Toolset package name, e.g., `llvm-toolset-7-clang`.  For
-    RHEL-based Linux distributions, specifying the version
-    automatically sets `extra_repository` to True.  The default is an
-    empty value.
+    actual compiler version.  For RHEL-based 8.x Linux distributions,
+    the version is ignored. The default is an empty value.
 
     # Examples
 
@@ -76,11 +72,11 @@ class llvm(bb_base, hpccm.templates.envvars):
     ```
 
     ```python
-    llvm(extra_repository=True, version='7')
+    llvm(version='7')
     ```
 
     ```python
-    llvm(nightly=True, version='11')
+    llvm(upstream=True, version='11')
     ```
 
     ```python
@@ -95,18 +91,22 @@ class llvm(bb_base, hpccm.templates.envvars):
 
         super(llvm, self).__init__(**kwargs)
 
+        # Current LLVM trunk version
+        self.__trunk_version = '12'
+
         self.__apt_keys = []       # Filled in below
         self.__apt_repositories = [] # Filled in below
         self.__commands = []       # Filled in below
         self.__compiler_debs = []  # Filled in below
         self.__compiler_rpms = []  # Filled in below
-        self.__extra_repo = kwargs.get('extra_repository', False)
         self.__extra_tools = kwargs.get('extra_tools', False)
-        self.__nightly = kwargs.get('nightly', False)
+        self.__openmp = kwargs.get('openmp', True)
         self.__ospackages = kwargs.get('ospackages', []) # Filled in below
         self.__runtime_debs = []   # Filled in below
         self.__runtime_ospackages = [] # Filled in below
         self.__runtime_rpms = []   # Filled in below
+        self.__toolset = kwargs.get('toolset', False)
+        self.__upstream = kwargs.get('upstream', False)
         self.__version = kwargs.get('version', None)
 
         # Output toolchain
@@ -128,21 +128,48 @@ class llvm(bb_base, hpccm.templates.envvars):
         if hpccm.config.g_linux_distro == linux_distro.UBUNTU:
             self.__ospackages = []
 
-            if self.__nightly and self.__version:
-                # Nightly packages from apt.llvm.org
-                if hpccm.config.g_cpu_arch != cpu_arch.X86_64:
-                    raise RuntimeError('LLVM nightly builds only available for x86')
+            if self.__upstream and not self.__version:
+                self.__version = self.__trunk_version
 
-                self.__compiler_debs = ['clang-{}'.format(self.__version),
-                                        'libomp-{}-dev'.format(self.__version)]
-                self.__runtime_debs = ['libclang1-{}'.format(self.__version),
-                                       'llvm-{}-runtime'.format(self.__version)]
-                self.__apt_keys = ['https://apt.llvm.org/llvm-snapshot.gpg.key']
-                self.__apt_repositories = self.__nightly_package_repos()
+            if self.__version:
+                if LooseVersion(self.__version) <= LooseVersion('6.0'):
+                    self.__compiler_debs = ['clang-{}'.format(self.__version)]
+                    self.__runtime_debs = [
+                        'libclang1-{}'.format(self.__version)]
 
-                self.__ospackages = ['apt-transport-https', 'ca-certificates',
-                                     'gnupg', 'wget']
-                self.__runtime_ospackages = self.__ospackages
+                    # Versioned OpenMP libraries do not exist for
+                    # older versions
+                    if self.__openmp:
+                        self.__compiler_debs.append('libomp-dev')
+                        self.__runtime_debs.append('libomp5')
+
+                else:
+                    self.__compiler_debs = ['clang-{}'.format(self.__version)]
+                    self.__runtime_debs = [
+                        'libclang1-{}'.format(self.__version)]
+
+                    if self.__openmp:
+                        self.__compiler_debs.append(
+                            'libomp-{}-dev'.format(self.__version))
+                        self.__runtime_debs.append(
+                            'libomp5-{}'.format(self.__version))
+
+                if self.__upstream:
+                    # Upstream packages from apt.llvm.org
+                    if hpccm.config.g_cpu_arch != cpu_arch.X86_64:
+                        raise RuntimeError('LLVM upstream builds only available for x86')
+
+                    self.__apt_keys = ['https://apt.llvm.org/llvm-snapshot.gpg.key']
+                    self.__apt_repositories = self.__upstream_package_repos()
+
+                    self.__runtime_debs.append(
+                        'llvm-{}-runtime'.format(self.__version))
+
+                    self.__ospackages = ['apt-transport-https',
+                                         'ca-certificates',
+                                         'gnupg', 'wget']
+
+                    self.__runtime_ospackages = self.__ospackages
 
                 # Setup the environment so that the alternate compiler
                 # version is the new default
@@ -150,39 +177,56 @@ class llvm(bb_base, hpccm.templates.envvars):
                 self.__commands.append('update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-{}) 30'.format(self.__version))
 
                 # Install and configure clang-format and clang-tidy
-                if self.__extra_tools:
+                if self.__toolset or self.__extra_tools:
                     self.__compiler_debs.extend([
                         'clang-format-{}'.format(self.__version),
                         'clang-tidy-{}'.format(self.__version)])
                     self.__commands.append('update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-{}) 30'.format(self.__version))
                     self.__commands.append('update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-{}) 30'.format(self.__version))
 
-            elif self.__version:
-                # distro provided version
-                self.__compiler_debs = ['clang-{}'.format(self.__version),
-                                        'libomp-dev']
-                self.__runtime_debs = ['libclang1', 'libomp5']
+                # Install and configure all packages
+                if self.__toolset:
+                    self.__compiler_debs.extend([
+                        'clang-tools-{}'.format(self.__version),
+                        'libc++-{}-dev'.format(self.__version),
+                        'libc++1-{}'.format(self.__version),
+                        'libc++abi1-{}'.format(self.__version),
+                        'libclang-{}-dev'.format(self.__version),
+                        'libclang1-{}'.format(self.__version),
+                        'liblldb-{}-dev'.format(self.__version),
+                        'lld-{}'.format(self.__version),
+                        'lldb-{}'.format(self.__version),
+                        'llvm-{}-dev'.format(self.__version),
+                        'llvm-{}-runtime'.format(self.__version),
+                        'llvm-{}'.format(self.__version)])
+                    self.__commands.append('update-alternatives --install /usr/bin/lldb lldb $(which lldb-{}) 30'.format(self.__version))
+                    self.__commands.append('update-alternatives --install /usr/bin/llvm-config llvm-config $(which llvm-config-{}) 30'.format(self.__version))
+                    self.__commands.append('update-alternatives --install /usr/bin/llvm-cov llvm-cov $(which llvm-cov-{}) 30'.format(self.__version))
 
-                # Setup the environment so that the alternate compiler
-                # version is the new default
-                self.__commands.append('update-alternatives --install /usr/bin/clang clang $(which clang-{}) 30'.format(self.__version))
-                self.__commands.append('update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-{}) 30'.format(self.__version))
-
-                # Install and configure clang-format and clang-tidy
-                if self.__extra_tools:
-                    self.__compiler_debs.append('clang-format-{}'.format(
-                        self.__version))
-                    self.__compiler_debs.append('clang-tidy-{}'.format(
-                        self.__version))
-                    self.__commands.append('update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-{}) 30'.format(self.__version))
-                    self.__commands.append('update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-{}) 30'.format(self.__version))
             else:
-                self.__compiler_debs = ['clang', 'libomp-dev']
-                self.__runtime_debs = ['libclang1', 'libomp5']
+                # Distro default
+                self.__compiler_debs = ['clang']
+                self.__runtime_debs = ['libclang1']
 
-                if self.__extra_tools:
+                if self.__openmp:
+                    self.__compiler_debs.append('libomp-dev')
+                    self.__runtime_debs.append('libomp5')
+
+                if self.__toolset or self.__extra_tools:
                     self.__compiler_debs.extend(['clang-format', 'clang-tidy'])
 
+                if self.__toolset:
+                    self.__compiler_debs.extend([
+                        'libc++-dev',
+                        'libc++1',
+                        'libc++abi1',
+                        'libclang-dev',
+                        'libclang1',
+                        'lldb',
+                        'llvm-dev',
+                        'llvm-runtime',
+                        'llvm'])
+
         elif hpccm.config.g_linux_distro == linux_distro.CENTOS:
             # Dependencies on the GNU compiler
             self.__ospackages = ['gcc', 'gcc-c++']
@@ -193,38 +237,59 @@ class llvm(bb_base, hpccm.templates.envvars):
             if self.__version:
                 if hpccm.config.g_linux_version >= StrictVersion('8.0'):
                     # Multiple versions are not available for CentOS 8
-                    self.__compiler_rpms = ['llvm-toolset-8.0.1']
-                    self.__runtime_rpms = ['llvm-libs-8.0.1', 'libomp']
+                    self.__compiler_rpms = ['clang', 'llvm-libs']
+                    self.__runtime_rpms = ['llvm-libs']
                     compiler_version = '8'
 
-                    if self.__extra_tools:
-                        self.__compiler_rpms.append('clang-tools-extra-8.0.1')
+                    if self.__openmp:
+                        self.__compiler_rpms.append('libomp')
+                        self.__runtime_rpms.append('libomp')
+
+                    if self.__toolset or self.__extra_tools:
+                        self.__compiler_rpms.append('clang-tools-extra')
+
+                    if self.__toolset:
+                        self.__compiler_rpms.append('llvm-toolset')
                 else:
                     # CentOS 7
                     self.__compiler_rpms = [
-                        'llvm-toolset-{}-clang'.format(self.__version),
-                        'llvm-toolset-{}-libomp-devel'.format(self.__version)]
+                        'llvm-toolset-{}-clang'.format(self.__version)]
                     self.__runtime_rpms = [
                         'llvm-toolset-{}-runtime'.format(self.__version),
-                        'llvm-toolset-{}-libomp'.format(self.__version),
                         'llvm-toolset-{}-compiler-rt'.format(self.__version)]
                     compiler_version = '4.8.2'
 
-                    if self.__extra_tools:
+                    if self.__openmp:
+                        self.__compiler_rpms.append(
+                            'llvm-toolset-{}-libomp-devel'.format(self.__version))
+                        self.__runtime_rpms.append(
+                            'llvm-toolset-{}-libomp'.format(self.__version))
+
+                    if self.__toolset or self.__extra_tools:
                         self.__compiler_rpms.append('llvm-toolset-{}-clang-tools-extra'.format(self.__version))
 
+                    if self.__toolset:
+                        self.__compiler_rpms.append('llvm-toolset-{}'.format(self.__version))
+
                     # Setup environment for devtoolset
                     self.environment_variables['PATH'] = '/opt/rh/llvm-toolset-{}/root/usr/bin:$PATH'.format(self.__version)
                     self.environment_variables['LD_LIBRARY_PATH'] = '/opt/rh/llvm-toolset-{}/root/usr/lib64:$LD_LIBRARY_PATH'.format(self.__version)
             else:
+                # Distro default
                 self.__compiler_rpms = ['clang']
                 if hpccm.config.g_linux_version >= StrictVersion('8.0'):
                     # CentOS 8
-                    self.__runtime_rpms = ['llvm-libs', 'libomp']
+                    self.__runtime_rpms = ['llvm-libs']
                     compiler_version = '8'
 
-                    if self.__extra_tools:
+                    if self.__openmp:
+                        self.__runtime_rpms.append('libomp')
+
+                    if self.__toolset or self.__extra_tools:
                         self.__compiler_rpms.append('clang-tools-extra')
+
+                    if self.__toolset:
+                        self.__compiler_rpms.append('llvm-toolset')
                 else:
                     # CentOS 7
                     self.__runtime_rpms = ['llvm-libs', 'libgomp']
@@ -233,6 +298,9 @@ class llvm(bb_base, hpccm.templates.envvars):
                     if self.__extra_tools: # pragma: no cover
                         logging.warning('llvm extra tools are not available for default CentOS 7, specify a LLVM version')
 
+                    if self.__toolset:
+                        self.__compiler_rpms.append('llvm')
+
             # The default llvm configuration for CentOS is unable to
             # locate some gcc components. Setup the necessary gcc
             # environment.
@@ -264,30 +332,37 @@ class llvm(bb_base, hpccm.templates.envvars):
             self += shell(commands=self.__commands)
         self += environment(variables=self.environment_step())
 
-    def __nightly_package_repos(self):
+    def __upstream_package_repos(self):
         """Return the package repositories for the given distro and llvm
         version.  The development branch repositories are not
         versioned and must be handled differently.  Currently the
-        development branch is version 11."""
+        development branch is version 12."""
 
         codename = 'xenial'
         codename_ver = 'xenial'
 
-        if (hpccm.config.g_linux_version >= StrictVersion('18.0') and
+        if (hpccm.config.g_linux_version >= StrictVersion('20.0') and
+            hpccm.config.g_linux_version < StrictVersion('21.0')):
+            codename = 'focal'
+            if self.__version == self.__trunk_version:
+                codename_ver = 'focal'
+            else:
+                codename_ver = 'focal-{}'.format(self.__version)
+        elif (hpccm.config.g_linux_version >= StrictVersion('18.0') and
             hpccm.config.g_linux_version < StrictVersion('19.0')):
             codename = 'bionic'
-            if self.__version == '11':
+            if self.__version == self.__trunk_version:
                 codename_ver = 'bionic'
             else:
                 codename_ver = 'bionic-{}'.format(self.__version)
         elif (hpccm.config.g_linux_version >= StrictVersion('16.0') and
               hpccm.config.g_linux_version < StrictVersion('17.0')):
             codename = 'xenial'
-            if self.__version == '11':
+            if self.__version == self.__trunk_version:
                 codename_ver = 'xenial'
             else:
                 codename_ver = 'xenial-{}'.format(self.__version)
-        else:
+        else: # pragma: no cover
             raise RuntimeError('Unsupported Ubuntu version')
 
         return [
@@ -306,13 +381,12 @@ class llvm(bb_base, hpccm.templates.envvars):
         Stage1 += l.runtime()
         ```
         """
-        instructions = []
-        instructions.append(comment('LLVM compiler runtime'))
+        self.rt += comment('LLVM compiler runtime')
         if self.__runtime_ospackages:
-            instructions.append(packages(ospackages=self.__runtime_ospackages))
-        instructions.append(packages(apt=self.__runtime_debs,
-                                     apt_keys=self.__apt_keys,
-                                     apt_repositories=self.__apt_repositories,
-                                     scl=bool(self.__version), # True / False
-                                     yum=self.__runtime_rpms))
-        return '\n'.join(str(x) for x in instructions)
+            self.rt += packages(ospackages=self.__runtime_ospackages)
+        self.rt += packages(apt=self.__runtime_debs,
+                            apt_keys=self.__apt_keys,
+                            apt_repositories=self.__apt_repositories,
+                            scl=bool(self.__version), # True / False
+                            yum=self.__runtime_rpms)
+        return str(self.rt)
