@@ -100,7 +100,7 @@ class yum(bb_base):
         self.__download_args = kwargs.get('download_args', '')
         self.__download_directory = kwargs.get(
             'download_directory',
-            posixpath.join(hpccm.config.g_wd, '/var/tmp/yum_download'))
+            posixpath.join(hpccm.config.g_wd, 'yum_download'))
         self.__epel = kwargs.get('epel', False)
         self.__extra_opts = kwargs.get('extra_opts', [])
         self.__extract = kwargs.get('extract', None)
