@@ -6,7 +6,7 @@ $ hpccm.py --recipe recipes/examples/basic.py --format docker
 """
 
 # Choose a base image
-Stage0.baseimage('ubuntu:16.04')
+Stage0 += baseimage(image='ubuntu:16.04')
 
 # Install GNU compilers (upstream)
 Stage0 += apt_get(ospackages=['gcc', 'g++', 'gfortran'])
